'''\
Module init
'''

from plugin import AzaxPluginError
from command import Command, checkRegisteredCommand_old
from event_type import EventType
from action import Action, checkRegisteredCommand
from selector_type import SelectorType, checkRegisteredSelector



'''\
The javascript compressor uses the 3rdparty packer module
that is taken from Plone's ResourceRegistries.'''

from thirdparty.packer import JavascriptPacker

jspacker_safe = JavascriptPacker('safe')
jspacker_full = JavascriptPacker('full')

def compress(data, compress_level):
    if compress_level == "safe":
        return jspacker_safe.pack(data)
    elif compress_level == "full":
        return jspacker_full.pack(data)
    else:
        # none
        return data




from plugin import AzaxPlugin
from interfaces import ISelectorType
import zope.component as capi
from zope.interface import implements

def checkRegisteredSelector(name):
    'Check if it is a registered selector.'
    try:
        command = capi.getUtility(ISelectorType, name)
    except capi.ComponentLookupError:
        raise AzaxPluginError, '"%s" is not a registered kss selector' % (name, )

class SelectorType(AzaxPlugin):
    '''The selectortype plugin

    '''

    implements(ISelectorType)

    def __init__(self, name, jsfile):
        AzaxPlugin.__init__(self, name, jsfile)



from zope.interface import Interface

class IAzaxPlugin(Interface):
    '''Base for azax plugins
    
    this represents an entity implemented in a javascript file
    '''

class ICommand(IAzaxPlugin):
    '''Command plugin'''

class IAction(IAzaxPlugin):
    '''Action plugin'''

class IEventType(IAzaxPlugin):
    '''Event type plugin'''

class ISelectorType(IAzaxPlugin):
    '''Selector type plugin'''

class ICommandSet(Interface):
    '''Command set plugin'''

class IParamProvider(IAzaxPlugin):
    '''Parameter provider plugin'''




from plugin import AzaxPlugin
from interfaces import ICommand
from plugin import AzaxPluginError
import zope.component as capi
from zope.interface import implements

def checkRegisteredCommand_old(name):
    'Check if it is a registered command.'
    try:
        command = capi.getUtility(ICommand, name)
    except capi.ComponentLookupError:
        raise AzaxPluginError, '"%s" is not a registered kss command' % (name, )

class Command(AzaxPlugin):
    '''The command plugin

    '''

    implements(ICommand)

    def __init__(self, name, jsfile):
        AzaxPlugin.__init__(self, name, jsfile)




from plugin import AzaxPlugin, AzaxPluginError
from interfaces import IAction
from zope.interface import implements
import zope.component as capi

def checkRegisteredCommand(name):
    'Check if it is a registered command.'
    try:
        command = capi.getUtility(IAction, name)
    except capi.ComponentLookupError:
        raise AzaxPluginError, '"%s" is not a registered kss command' % (name, )
    # check if the action has a valid command factory
    if command.command_factory == 'none':
        raise AzaxPluginError, '"%s" kss command has missing command_factory' % (name, )
    # issue deprecation warning, if necessary
    command.check_deprecation()

class Action(AzaxPlugin):
    '''The action plugin

    '''

    implements(IAction)

    def __init__(self, name, jsfile, command_factory, 
            params_mandatory, params_optional, deprecated):
        AzaxPlugin.__init__(self, name, jsfile)
        self.command_factory = command_factory
        self.params_mandatory = params_mandatory
        self.params_optional = params_optional
        self.deprecated = deprecated

    def check_deprecation(self):
        if self.deprecated:
            import warnings, textwrap
            warnings.warn(textwrap.dedent('''\
            The usage of the kss command "%s" is deprecated,
            %s''' % (self.name, self.deprecated)), DeprecationWarning, 2)



from kss.core.selectors import Selector, CssSelector, HtmlIdSelector
from kss.core.selectors import ParentNodeSelector, SameNodeSelector
from kss.core.azaxview import CommandSet
from kss.core.deprecated import deprecated
from kss.core.parsers import HtmlParser
from kss.core.plugins.core.interfaces import IKSSCoreCommands
from zope.interface import implements

class KSSCoreCommands(CommandSet):
    implements(IKSSCoreCommands)

    def getSelector(self, type, selector):
        'Get a selector of a given type'
        return Selector(type, selector)

    def getCssSelector(self, selector):
        return CssSelector(selector)
            
    def getHtmlIdSelector(self, selector):
        return HtmlIdSelector(selector)

    def getSameNodeSelector(self, selector):
        return SameNodeSelector(selector)

    def getParentNodeSelector(self, selector):
        return ParentNodeSelector(selector)

    # XXX the list is not full: maybe complete them?
    
    def replaceInnerHTML(self, selector, new_value, withKssSetup='True'):
        """ see interfaces.py """
        new_value = HtmlParser(new_value)().encode('ascii', 'xmlcharrefreplace')
        command = self.commands.addCommand('replaceInnerHTML', selector)
        data = command.addParam('html', new_value)
        data = command.addParam('withKssSetup', withKssSetup)

    def replaceHTML(self, selector, new_value, withKssSetup='True'):
        """ see interfaces.py """
        new_value = HtmlParser(new_value)().encode('ascii', 'xmlcharrefreplace')
        command = self.commands.addCommand('replaceHTML', selector)
        data = command.addParam('html', new_value)
        data = command.addParam('withKssSetup', withKssSetup)
    
    def setAttribute(self, selector, name, value):
        """ see interfaces.py """
        command = self.commands.addCommand('setAttribute', selector)
        data = command.addParam('name', name)
        data = command.addParam('value', value)

    def setStyle(self, selector, name, value):
        """ see interfaces.py """
        command = self.commands.addCommand('setStyle', selector)
        data = command.addParam('name', name)
        data = command.addParam('value', value)
    
    def insertHTMLAfter(self, selector, new_value, withKssSetup='True'):
        """ see interfaces.py """
        new_value = HtmlParser(new_value)().encode('ascii', 'xmlcharrefreplace')
        command = self.commands.addCommand('insertHTMLAfter', selector)
        data = command.addParam('html', new_value)
        data = command.addParam('withKssSetup', withKssSetup)

    def insertHTMLAsFirstChild(self, selector, new_value, withKssSetup='True'):
        """ see interfaces.py """
        new_value = HtmlParser(new_value)().encode('ascii', 'xmlcharrefreplace')
        command = self.commands.addCommand('insertHTMLAsFirstChild', selector)
        data = command.addParam('html', new_value)
        data = command.addParam('withKssSetup', withKssSetup)

    def insertHTMLAsLastChild(self, selector, new_value, withKssSetup='True'):
        """ see interfaces.py """
        new_value = HtmlParser(new_value)().encode('ascii', 'xmlcharrefreplace')
        command = self.commands.addCommand('insertHTMLAsLastChild', selector)
        data = command.addParam('html', new_value)
        data = command.addParam('withKssSetup', withKssSetup)

    def insertHTMLBefore(self, selector, new_value, withKssSetup='True'):
        """ see interfaces.py """
        new_value = HtmlParser(new_value)().encode('ascii', 'xmlcharrefreplace')
        command = self.commands.addCommand('insertHTMLBefore', selector)
        data = command.addParam('html', new_value)
        data = command.addParam('withKssSetup', withKssSetup)

    def clearChildNodes(self, selector):
        """ see interfaces.py """
        command = self.commands.addCommand('clearChildNodes', selector)
    
    def deleteNode(self, selector):
        """ see interfaces.py """
        command = self.commands.addCommand('deleteNode', selector)

    def deleteNodeAfter(self, selector):
        """ see interfaces.py """
        command = self.commands.addCommand('deleteNodeAfter', selector)

    def deleteNodeBefore(self, selector):
        """ see interfaces.py """
        command = self.commands.addCommand('deleteNodeBefore', selector)

    def copyChildNodesFrom(self, selector, id):
        """ see interfaces.py """
        command = self.commands.addCommand('copyChildNodesFrom', selector)
        data = command.addParam('html_id', id)

    def moveNodeAfter(self, selector, id):
        """ see interfaces.py """
        command = self.commands.addCommand('moveNodeAfter', selector)
        data = command.addParam('html_id', id)

    def copyChildNodesTo(self, selector, id):
        """ see interfaces.py """
        command = self.commands.addCommand('copyChildNodesTo', selector)
        data = command.addParam('html_id', id)

    def setStateVar(self, varname, value):
        """ see interfaces.py """
        command = self.commands.addCommand('setStateVar')
        command.addParam('varname', varname)
        command.addParam('value', value)

    def triggerEvent(self, name, **kw):
        """ see interfaces.py """
        command = self.commands.addCommand('triggerEvent')
        command.addParam('name', name)
        for key, value in kw.iteritems():
            command.addParam(key, value)

    def toggleClass(self, selector, classname):
        """ see interfaces.py """
        command = self.commands.addCommand('toggleClass', selector)
        data = command.addParam('classname', classname)

    def focus(self, selector):
        """ see interfaces.py """
        command = self.commands.addCommand('focus', selector)

    # XXX Deprecated ones

    def moveChildrenTo(self, selector, id):
        """ see interfaces.py """
        self.copyChildrenTo(selector, id)
        self.clearChildren(selector)
    moveChildrenTo = deprecated(moveChildrenTo, 'No more supported, use a sequence of copyChildrenTo and clearChildren')

    setHtmlAsChild = deprecated(replaceInnerHTML, 'use replaceInnerHTML instead')
    addAfter = deprecated(insertHTMLAfter, 'use insertHTMLAfter instead')
    clearChildren = deprecated(clearChildNodes, 'use clearChildNodes instead')
    removeNode = deprecated(deleteNode, 'use deleteNode instead')
    removeNextSibling = deprecated(deleteNodeAfter, 'use deleteNodeAfter instead')
    removePreviousSibling = deprecated(deleteNodeBefore, 'use deleteNodeBefore instead')
    copyChildrenFrom = deprecated(copyChildNodesFrom, 'use copyChildNodesFrom instead')
    copyChildrenTo = deprecated(copyChildNodesTo, 'use copyChildNodesTo instead')
    setStatevar = deprecated(setStateVar, 'use setStateVar (capital V) instead')

    # end deprecated




from plugin import AzaxPlugin
from interfaces import IEventType
from zope.interface import implements

class EventType(AzaxPlugin):
    '''The event type plugin

    '''

    implements(IEventType)

    def __init__(self, name, jsfile):
        AzaxPlugin.__init__(self, name, jsfile)




# Copyright (c) 2006
# Authors:
#   Godefroid Chapelle <gotcha@bubblenet.be>
#   Balazs Ree <ree@greenfinity.hu>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
# 02111-1307, USA.
#
__all__ = ('AzaxBaseView', 'force_unicode', 'AzaxUnicodeError', 
           'KssExplicitError', 'kssaction',
           'CommandSet', 'ICommandSet',
        ) 

import mimetypes

mimetypes.types_map['.kkt'] = 'text/xml'    # BBB legacy!
mimetypes.types_map['.kukit'] = 'text/xml'

from kss.core.azaxview import KSSView, CommandSet
from kss.core.actionwrapper import KssExplicitError, kssaction 
from kss.core.unicode_quirks import force_unicode, AzaxUnicodeError
from kss.core.interfaces import ICommandSet

# BBB
from kss.core.azaxview import AzaxBaseView

try:
    import Products.Five
except ImportError:
    pass
else:
    # Allow API to build commands from restricted code
    from AccessControl import allow_module
    allow_module('kss.core.ttwapi')




# -*- coding: latin-1 -*-
# Copyright (c) 2005-2006
# Authors:
#   Godefroid Chapelle <gotcha@bubblenet.be>
#   Tarek Ziadé <tz@nuxeo.com>
#   Balázs Reé <ree@greenfinity.hu>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
# 02111-1307, USA.
#
from textwrap import dedent

import warnings
from Testing.ZopeTestCase import ZopeTestCase, FunctionalTestCase
from OFS.SimpleItem import SimpleItem

from zope import interface
from zope.publisher.browser import TestRequest
from zope.publisher.interfaces.browser import IBrowserRequest
from zope.app.testing import placelesssetup

import kss.core
from kss.core import KSSView



class KSSCoreLayer:
    @classmethod
    def setUp(cls):
        try:
            import Products.Five
        except ImportError:
            # probably zope 3
            pass
            # XXX TODO fix this?? --- never run yet on Z3
            from zope.configuration.xmlconfig import XMLConfig
            XMLConfig('tests/configure-unittest.zcml', kss.core)()
        else:
            from Products.Five.zcml import load_string, load_config
            load_config('meta.zcml', package=Products.Five)

            try:
                load_config('traversing.zcml', package=Products.Five)
            except IOError:
                # Let's try the Zope 2.9 way (zope.app.traversing is
                # moved in 2.10)
                load_string(dedent('''\
                <configure xmlns="http://namespaces.zope.org/zope"
                           xmlns:five="http://namespaces.zope.org/five">
                  <include package="zope.app.traversing" />
                  <adapter
                       for="*"
                       factory="Products.Five.traversable.FiveTraversable"
                       provides="zope.app.traversing.interfaces.ITraversable"
                       />
                   <adapter
                       for="*"
                       factory="zope.app.traversing.adapters.Traverser"
                       provides="zope.app.traversing.interfaces.ITraverser"
                       />
                </configure>'''))
            # Load the permissions config, if it's there
            try:
                load_config('permissions.zcml', package=Products.Five)
            except IOError:
                # Zope 2.10 / Five 1.3.6 does not have it
                pass
            load_config('configure-unittest.zcml', package=kss.core.tests)

    @classmethod
    def tearDown(cls):
        placelesssetup.tearDown()
    

class KSSLayer(KSSCoreLayer):
    @classmethod
    def setUp(cls):
        try:
            from Products.Five.zcml import load_string, load_config
        except ImportError:
            raise ImportError("KSSLayer requires Five to be installed.")
        load_config('meta.zcml', package=kss.core)
        load_config('configure.zcml', package=kss.core)

# Test view
class TestView(KSSView):
    def testMethod(self):
        'Yes.'

# Debug request
# This has a modified render.

class IDebugRequest(IBrowserRequest):
    'The debug request'

class KssViewTestCase(ZopeTestCase):
    layer = KSSLayer

    def loadCoreConfig(self, kss_core=True):
        warnings.warn(
            "KSS tests are now using layers.  Please do not use "
            "loadCoreConfig anymore.",
            DeprecationWarning)
    
    def createView(self):
        "Set up a fake view (with no content)"
        self.view = self.folder.restrictedTraverse('testMethod')
        return self.view

    def setDebugRequest(self):
        'commands will be rendered as test friendly data structures'
        request = self.folder.REQUEST
        interface.directlyProvides(
            request,
            interface.directlyProvidedBy(request) + IDebugRequest)

class KssViewFunctionalTestCase(FunctionalTestCase, KssViewTestCase):
    'Functional test base'


# backward compatibility
AzaxViewTestCase = KssViewTestCase




from plugin import AzaxPlugin
from interfaces import IParamProvider
import zope.component as capi
from zope.interface import implements

class ParamProvider(AzaxPlugin):
    '''The parameter provider plugin
    '''

    implements(IParamProvider)

    def __init__(self, name, jsfile):
        AzaxPlugin.__init__(self, name, jsfile)



# -*- coding: ISO-8859-15 -*-
# Copyright (c) 2006
# Authors:
#   Godefroid Chapelle <gotcha@bubblenet.be>
#   Balazs Ree <ree@greenfinity.hu>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
# 02111-1307, USA.
#
'''\
Marshal objects

These build up the response and get marshalled to the client
in the defined format
'''

from zope.interface import implements
from zope.app.pagetemplate.viewpagetemplatefile import ViewPageTemplateFile
from interfaces import IAzaxCommands, IAzaxCommand, IAzaxParam, IAzaxCommandView
from unicode_quirks import force_unicode
from zope.interface import Interface
import zope.component
from parsers import XmlParser, HtmlParser
from pluginregistry import checkRegisteredCommand_old
from pluginregistry import checkRegisteredCommand, checkRegisteredSelector, \
        AzaxPluginError

class AzaxCommands(list):
    implements(IAzaxCommands)
 
    def addCommand(self, command_name, selector=None, **kw):
        command = AzaxCommand(command_name, selector=selector, **kw)
        self.append(command)
        return command
   
    def render(self, request):
        '''All methods must use this to return their command set
        '''
        adapter = zope.component.getMultiAdapter((self, request), IAzaxCommandView)
        return adapter.render()

class AzaxParam:
    implements(IAzaxParam)
    
    def __init__(self, name, content=''):
        self.name = name
        self.content = content

    def force_content_unicode(self):
        # Content must be str with ascii encoding, or unicode!
        self.content = force_unicode(self.content)

    def getName(self):
        return self.name

    def getContent(self):
        return self.content
        
class AzaxCommand:
    implements(IAzaxCommand)
    
    def __init__(self, command_name, selector=None, **kw):
        try:
            checkRegisteredCommand_old(command_name)
        except AzaxPluginError:
            # we expect this is not registered as command, anyway
            # so check it as an action.
            checkRegisteredCommand(command_name)
        else:
            # ok. XXX this will be deprecated
            # All registerCommand commands are obsolete, by default
            import warnings, textwrap
            warnings.warn(textwrap.dedent('''\
            The usage of the kss command "%s" is deprecated''' 
                % (command_name, )), DeprecationWarning, 2)
        if selector is not None:
            if isinstance(selector, basestring): 
                # the default selector - given just as a string
                self.selector = selector
                self.selectorType = ''
            else:
                checkRegisteredSelector(selector.type)
                self.selector = selector.value
                self.selectorType = selector.type
        else:
            self.selector = None
            self.selectorType = None
        self.name = command_name
        self.params = []
        # Add parameters passed in **kw
        for key, value in kw.iteritems():
            self.addParam(key, value)

    # --
    # Different parameter conversions
    # --

    # REMARK: with the jsonserver product present, you can
    # just send complex data types directly with AddParam

    def addParam(self, name, content=''):
        'Add the param as is'
        param = AzaxParam(name, content)
        self.params.append(param)
        return param

    #
    # Some helpers
    #

    def addUnicodeParam(self, name, content=''):
        'Add the param as unicode'
        self.addParam(name, content=content)

    def addStringParam(self, name, content='', encoding='utf'):
        'Add the param as an encoded string, by default UTF-8'
        content = unicode(content, 'utf')
        self.addParam(name, content=content)

    def addHtmlParam(self, name, content=''):
        'Add the param as an HTML content.'
        content = HtmlParser(content)().encode('ascii', 'xmlcharrefreplace')
        self.addParam(name, content=content)

    def addXmlParam(self, name, content=''):
        'Add the param as XML content'
        content = XmlParser(content)().encode('ascii', 'xmlcharrefreplace')
        self.addParam(name, content=content)

    def addCdataParam(self, name, content=''):
        'Add the param as a CDATA node'
        content = '<![CDATA[%s]]>' % (content, )
        self.addParam(name, content=content)


    # --
    # Accessors, not sure if we need them
    # --

    def getName(self):
        return self.name

    def getSelector(self):
        return self.selector

    def getSelectorType(self):
        return self.selectorType

    def getParams(self):
        return self.params

class CommandView(object):
    '''View of a command.
    
    The render method does actual marshalling
    of the commands to be sent to the client.
    '''
    implements(IAzaxCommandView)

    def __init__(self, context, request):
        self.context = context
        self.request = request
        # XXX From Zope2.9 we need this.
        # Note: We don't use proper views for Five. As our context object
        # is not even a proper Zope content. There would be a way to:
        #
        # - use ZopeTwoPageTemplateFile
        # - and, make the object to be proper zope content.
        #
        # This would be two much ado for nothing, so we just use barefoot
        # rendering but as a consequence no path expression, only python:
        # is available from the page template.
        if not hasattr(self.request, 'debug'):
            self.request.debug = None

        # Force parameters content to be unicode
        for command in context:
            for param in command.getParams():
                param.force_content_unicode()
    
    # XML output gets rendered via a page template
    # XXX note: barefoot rendering, use python: only after zope2.9
    # XXX we must have the content type set both here and below
    _render = ViewPageTemplateFile('browser/kukitresponse.pt', content_type='text/xml;charset=utf-8')

    def render(self):
        result = self._render()
        # Always output text/xml to make sure browsers but the data in the
        # responseXML instead of responseText attribute of the
        # XMLHttpRequestobject.
        self.request.RESPONSE.setHeader('Content-type', 'text/xml;charset=utf-8')
        return result



import zope.component as capi
from interfaces import IAzaxPlugin
from zope.interface import implements
# concatresource is an embedded product 
import _concatresource
from concatresource.interfaces import IConcatResourceAddon
from json import getJsonAddonFiles
import zope.component as capi

class AzaxConcatResourceAddon(object):
    implements(IConcatResourceAddon)
    
    def getAddonFiles(self):
        try:
            files = self._addon_files
        except AttributeError:
            # Lazy setup of addon files
            self._addon_files = files = getJsonAddonFiles()
            # Lookup all utilities and add up the files from it
            plugins = capi.getAllUtilitiesRegisteredFor(IAzaxPlugin)
            for plugin in plugins:
                if plugin.jsfile and plugin.jsfile not in files:
                    files.append(plugin.jsfile)
        return files

azaxConcatResourceAddon = AzaxConcatResourceAddon()



'''\
Preprocess resource files by applying compression on them
'''

__all__ = ('compress', )

from javascript import compress as compress_javascript
from css import compress as compress_css

compress_methods = {    
    'application/x-javascript': compress_javascript,
    'text/css': compress_css,
    }

default_compress_method = lambda text: text

def compress(data, content_type, compress_level):
    'Returns compressed text for a given content type'
    method = compress_methods.get(content_type, default_compress_method)
    return method(data, compress_level)




from interfaces import IAzaxPlugin
import zope.component as capi
from zope.interface import implements

class AzaxPluginError(Exception):
    pass
 
def registerPlugin(cls, interface, name, *arg, **kw):
    'Convenience method to help registration'
    plugin = cls(name, *arg, **kw)
    # check if it's registered: do not allow registration for the second name
    try:
        capi.getUtility(interface, name=name)
    except capi.ComponentLookupError:
        pass
    else:
        raise AzaxPluginError, 'Duplicate registration attempt for plugin "%s" of type %s' % (plugin.name, interface)
    # provide the utility.
    capi.provideUtility(plugin, interface, name=name)

class AzaxPlugin(object):
    'The base plugin class'

    implements(IAzaxPlugin)

    def __init__(self, name, jsfile):
        self.name = name
        self.jsfile = jsfile



from zope.interface import implements
import zope.component as capi

from plugin import AzaxPluginError
from plugin import registerPlugin
from interfaces import ICommandSet

def getRegisteredCommandSet(name):
    'Get the command set'
    try:
        commandset = capi.getUtility(ICommandSet, name)
    except capi.ComponentLookupError:
        raise AzaxPluginError, '"%s" is not a registered kss command set' % (name, )
    return commandset

class CommandSet(object):
    '''The command set plugin

    registers the command adapter interface
    (like IKssCoreCommands), this makes possible
    to look them up by name instead of by interface
    '''

    implements(ICommandSet)

    def __init__(self, name, provides):
        self.name = name
        self.provides = provides

def registerAndAllowCommandSet(class_, name, provides, *arg, **kw):
    registerPlugin(CommandSet, ICommandSet, name, provides, *arg, **kw)
    try:
        import Products.Five
    except ImportError:
        pass
    else:
        # Allow TTW to use commandsets
        from AccessControl import allow_class
        allow_class(class_)
    



from interfaces import IScriptaculousEffectsCommands
from kss.core.azaxview import CommandSet

class ScriptaculousEffectsCommands(CommandSet):

    def effect(self, selector, type):
        """ see interfaces.py """
        command = self.commands.addCommand('effect', selector)
        data = command.addParam('type', type)




'''\
The css compressor uses the 3rdparty packer module
that is taken from Plone's ResourceRegistries.
'''

from thirdparty.packer import CSSPacker

csspacker_safe = CSSPacker('safe')
csspacker_full = CSSPacker('full')

def compress(data, compress_level):
    if compress_level == "safe":
        return csspacker_safe.pack(data)
    elif compress_level == "full":
        return csspacker_full.pack(data)
    else:
        # none
        return data



from setuptools import setup, find_packages
import sys, os

version = '1.2-beta2'

setup(name='kss.core',
      version=version,
      description="KSS (Kinetic Style Sheets) core framework",
      long_description="""\
""",
      # Get more strings from http://www.python.org/pypi?%3Aaction=list_classifiers
      classifiers=[
        "Framework :: Zope2",
        "Framework :: Zope3",
        "Programming Language :: Python",
        "Topic :: Software Development :: Libraries :: Python Modules",
        ],
      keywords='',
      author='KSS Project',
      author_email='kss-devel@codespeak.net',
      url='http://kssproject.org',
      license='GPL',
      packages=find_packages(exclude=['ez_setup']),
      namespace_packages=['kss'],
      include_package_data=True,
      zip_safe=False,
      install_requires=[
          'setuptools',
      ],
      entry_points="""
      # -*- Entry points: -*-
      """,
      )




class AzaxUnicodeError(RuntimeError):
    pass

def force_unicode(value, encoding='ascii'):
    'Force value to be unicode - allow also value in a specific encoding (by default, ascii).'
    if isinstance(value, str):
        try:
            value = unicode(value, encoding)
        except UnicodeDecodeError, exc:
            raise AzaxUnicodeError, 'Content must be unicode or ascii string, original exception: %s' % (exc, )
    else:
        assert isinstance(value, unicode)
    return value
